@@ -22,6 +22,12 @@
 #ifndef __CVSGRAPH_H
 #define __CVSGRAPH_H
 
+#define CONFFILENAME	"cvsgraph.conf"
+
+#ifndef ETCDIR
+# define ETCDIR		"/usr/local/etc"
+#endif
+
 #define DEBUG_CONF_LEX		0x01
 #define DEBUG_CONF_YACC		0x02
 #define DEBUG_RCS_LEX		0x04
@@ -30,7 +36,12 @@
 
 extern int debuglevel;
 
-typedef gdFontPtr	font_t;
+typedef struct __font_t
+{
+	gdFontPtr	gdfont;
+	char		*ttfont;
+	double		ttsize;
+} font_t;
 
 typedef struct __color_t
 {
@@ -47,7 +58,15 @@ typedef struct __config_t
 	char	*date_format;
 
 	color_t	color_bg;
+	int	transparent_bg;
 	int	box_shadow;
+	int	upside_down;
+	int	strip_untagged;
+	int	strip_first_rev;
+	int	auto_stretch;
+	int	use_ttf;
+	int	anti_alias;
+	int	thick_lines;
 
 	font_t	tag_font;
 	color_t	tag_color;
@@ -68,6 +87,8 @@ typedef struct __config_t
 
 	font_t	branch_font;
 	color_t	branch_color;
+	font_t	branch_tag_font;
+	color_t	branch_tag_color;
 	color_t	branch_bgcolor;
 	int	branch_lspace;
 	int	branch_rspace;
@@ -75,6 +96,7 @@ typedef struct __config_t
 	int	branch_bspace;
 	int	branch_connect;
 	int	branch_margin;
+	int	branch_dupbox;
 
 	char	*title;
 	int	title_x;
